@@ -21,7 +21,7 @@
 
 #include "math_private.h"
 
-DLLEXPORT int
+OLM_DLLEXPORT int
 ilogbf(float x)
 {
 	int32_t hx,ix;
