@@ -17,7 +17,7 @@
 #include "fpmath.h"
 #include "math_private.h"
 
-DLLEXPORT long double
+OLM_DLLEXPORT long double
 logbl(long double x)
 {
 	union IEEEl2bits u;
