@@ -32,7 +32,7 @@
 
 #include "math_private.h"
 
-DLLEXPORT double
+OLM_DLLEXPORT double
 scalbln (double x, long n)
 {
 	int in;
@@ -47,7 +47,7 @@ scalbln (double x, long n)
 	return (scalbn(x, in));
 }
 
-DLLEXPORT float
+OLM_DLLEXPORT float
 scalblnf (float x, long n)
 {
 	int in;
@@ -62,7 +62,7 @@ scalblnf (float x, long n)
 	return (scalbnf(x, in));
 }
 
-DLLEXPORT long double
+OLM_DLLEXPORT long double
 scalblnl (long double x, long n)
 {
 	int in;
